﻿/**
 * WCFを使用したサンプルプログラム9: ダイレクト印刷を行うサンプルプログラムです。
 * 
 * [本サンプルの実行手順]
 * 
 * <pre>
 * 1. Visual Studio 2008以上で新規プロジェクトを作成する (以下は2008での表示名)
 * 1.1 プロジェクト名は「BizStreamWebApplication」
 * 1.2 「プロジェクトの種類」は「Visual C# / Web」
 * 1.3 「テンプレート」は「ASP.NET Webアプリケーション」
 * 2. 「ソリューションエクスプローラ」にて右クリック後、「サービス参照の追加..」をクリックする
 * 2.1 「アドレス」には「http://wsssrv:8080/axis2/services/bizstream?wsdl」を入力し「移動」をクリックする
 * 2.2 認証を要求されるので、ユーザ名を「bizuser1」、パスワードを「bizuser1」と入力し「OK」をクリックする
 * 2.3 「名前空間」には「BizStreamServiceReference」を入力し「OK」をクリックする
 * 3. 「ソリューションエクスプローラ」にて右クリック後、「参照」>「参照の追加」を右クリックする
 * 3.1 「bsdpc.dll」および「Ionic.Zip.dll」を参照に追加する
 * 4. 本サンプルを上記プロジェクトに上書きし、ビルド後、実行する
 * </pre>
 * 
 * @author Copyright 2001-2018 BrainSellers.com Corp. All Rights Reserved.
 * @version 1.0.2
 * @since 4.9.0
 */

using System;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.Web;
using BizStreamWebApplication.BizStreamServiceReference;
using com.brainsellers.bizstream.directprint;

namespace BizStreamWebApplication
{
    public partial class WSS_WCF_Sample9 : System.Web.UI.Page
    {
        // Webサービスサーバのホスト名
        const string WSS_HOST_NAME = "wsssrv";

        // ユーザアプリケーションサーバのホスト名:ポート名
        const string AP_HOST_NAME = "localhost:50000";

        // プリンタ名
        const string PRINTER_NAME = "FinePrint";

        // Webサービスサーバ上のサンプルディレクトリの場所
        const string WSS_BIZSTREAM_SAMPLE_DIR = "\\bs\\sample";

        // Webサービスのエンドポイントプリフィックス
        const string WSS_SERVICE_LOCATION = "http://" + WSS_HOST_NAME + ":8080/axis2/services";

        // BASIC認証のユーザ名
        const string USER_NAME = @"bizuser1";

        // BASIC認証のパスワード
        const string PASSWORD = @"bizuser1";

        // 監査ロギング用のユーザ定義
        const string USER_DEF = "AAA";

        // 入力レイアウト定義ファイル名
        const string LAYOUT_FILE = WSS_BIZSTREAM_SAMPLE_DIR + "\\xml\\Sample1.xml";
        
        // 印刷結果応答URL
        const string RESPONSE_URL = "http://" + AP_HOST_NAME + "/WSS_WCF_Sample9_1.aspx";


        protected void Page_Load(object sender, EventArgs e)
        {
            // データの生成
            byte[] data = generate();

            // ダイレクト印刷ストリームの作成
            PDFDirectPrintStream direct = new PDFDirectPrintStream(Response);
            // 印刷応答URL
            direct.setResponseUrl(RESPONSE_URL);
            // 出力PDFファイル
//            direct.setSaveFileName("C:/Temp/WSS_WCF_Sample9.pdf");
            // プリンタ名
            direct.setPrinterName(PRINTER_NAME);
            // 印刷部数
            direct.setNumberOfCopy(1);
            // 出力トレイ
            direct.setSelectedTray(PDFDirectPrintStream.TRAY_AUTO);
            // 印刷ジョブ名
            direct.setJobName("WSS_WCF_Sample9");
            // 印刷ダイアログ表示
            direct.setPrintDialog(false);
            // ブラウザのターゲットフレーム名 (IEでのみ有効)
            direct.setTarget("bizPrint");
            // sppファイル暗号化パスワード
//            direct.setPassword("password");
            // エンコード済み暗号化パスワード
//            direct.setPasswordWithEncoded("cGFzc3dvcmQ=");
            // 用紙に合わせて印刷
            direct.setDoFit(true);
            // 印刷開始ページ
            direct.setFromPage(1);
            // 印刷終了ページ
            direct.setToPage(-1);

            // PDFをストリームに書き出す
            direct.Write(data);
            direct.Close();
        }

        private byte[] generate()
        {
            // クライアントを生成
            bizstreamPortTypeClient client =
                new bizstreamPortTypeClient("BizstreamSOAP11port",
                    WSS_SERVICE_LOCATION + "/bizstream?UserDef=" + USER_DEF);

            // 認証の設定
            BindingElementCollection elements = client.Endpoint.Binding.CreateBindingElements();
            elements.Find<HttpTransportBindingElement>().AuthenticationScheme =
                System.Net.AuthenticationSchemes.Basic;
            client.ClientCredentials.UserName.UserName = USER_NAME;
            client.ClientCredentials.UserName.Password = PASSWORD;

            // MTOMを有効化
            elements.Remove<TextMessageEncodingBindingElement>();
            MtomMessageEncodingBindingElement mtom = new MtomMessageEncodingBindingElement();
            mtom.ReaderQuotas.MaxStringContentLength = 100000;
            elements.Insert(0, mtom);
            elements.Find<HttpTransportBindingElement>().KeepAliveEnabled = false;
            client.Endpoint.Binding = new CustomBinding(elements);

            // リクエストメッセージの作成
            generateDataRequest request = new generateDataRequest();

            // 出力ファイルの種類を設定
            request.dataType = new dataType();
            request.dataType.Item = new pdf();

            // レイアウト定義を設定
            request.layoutData = new layoutDefinition[1];
            request.layoutData[0] = new layoutDefinition();
            request.layoutData[0].uri = LAYOUT_FILE;

            // リクエストを送信
            fileData data = client.generateData(request);

            return data.contentData.Value;
        }
    }
}
